@@ -17,19 +17,19 @@
 
 static char
   /* Command codes for Yaesu FT847/FT857 CAT */
-  FT847_CAT_ON[]	= { 0, 0, 0, 0, (char)0x00 }, /*  Enable CAT */
-  FT847_CAT_OFF[]	= { 0, 0, 0, 0, (char)0x80 }, /* Disable CAT */
-  FT847_MAIN_VFO[]	= { 0, 0, 0, 0, (char)0x03 }, /* Read main VFO freq */
-  FT847_SET_VFO[]	= { 0, 0, 0, 0, (char)0x01 }, /* Set main VFO freq  */
+  FT847_CAT_ON[]    = { 0, 0, 0, 0, (char)0x00 }, /*  Enable CAT */
+  FT847_CAT_OFF[]   = { 0, 0, 0, 0, (char)0x80 }, /* Disable CAT */
+  FT847_MAIN_VFO[]  = { 0, 0, 0, 0, (char)0x03 }, /* Read main VFO freq */
+  FT847_SET_VFO[]   = { 0, 0, 0, 0, (char)0x01 }, /* Set main VFO freq  */
   FT847_MODE_CWR[]  = { (char)0x03, 0, 0, 0, (char)0x07 }, /* Set mode to CWR */
   FT847_MODE_CWNR[] = { (char)0x83, 0, 0, 0, (char)0x07 }, /* Set mode to CWNR */
 
   /* Command codes for Elecraft K3 */
-  K3_K31_S[] = "K31;",				/* Set K3 CAT mode */
-  K3_K31_G[] = "K3;",				/* Request K3 CAT mode */
-  K3_VFOA_S[] = "FAnnnnnnnnnnn;",	/* Set VFO A frequency */
-  K3_VFOA_G[] = "FA;",				/* Get VFO A frequency */
-  K3_MODE_CWR[] = "MD7;";			/* Set mode to CWR */
+  K3_K31_S[] = "K31;",              /* Set K3 CAT mode */
+  K3_K31_G[] = "K3;",               /* Request K3 CAT mode */
+  K3_VFOA_S[] = "FAnnnnnnnnnnn;",   /* Set VFO A frequency */
+  K3_VFOA_G[] = "FA;",              /* Get VFO A frequency */
+  K3_MODE_CWR[] = "MD7;";           /* Set mode to CWR */
 
 /* Serial port File descriptor */
 static int serial_fd = 0;
@@ -68,29 +68,28 @@ Read_Tcvr_Serial( char *data, size_t len )
   int nbytes = 0, cnt = 0;
 
   /* Check for data to be available */
-  if( isFlagClear(TCVR_SERIAL_TEST) &&
-	  isFlagClear(CAT_SETUP) )
-	return( FALSE );
+  if( isFlagClear(TCVR_SERIAL_TEST) && isFlagClear(CAT_SETUP) )
+    return( FALSE );
   while( ++cnt < MAX_SERIAL_RETRIES )
   {
-	ioctl( serial_fd, FIONREAD, &nbytes);
-	if( nbytes == (int)len ) break;
-	fprintf( stderr,
-		"xdemorse: read(): incorrect number of bytes available:"
-		" %d/%d\n", nbytes, (int)len );
-	usleep( 100000 );
+    ioctl( serial_fd, FIONREAD, &nbytes);
+    if( nbytes == (int)len ) break;
+    fprintf( stderr,
+        "xdemorse: read(): incorrect number of bytes available:"
+        " %d/%d\n", nbytes, (int)len );
+    usleep( 100000 );
   }
 
   /* Error condition */
   if( cnt >= MAX_SERIAL_RETRIES )
   {
-	tcflush( serial_fd, TCIOFLUSH );
-	fprintf( stderr,
-		"xdemorse: read(): incorrect number of bytes available:"
-		" %d/%d after %d tries\n", nbytes, (int)len, cnt );
-	data[0] = '\0';
-	Cancel_CAT();
-	return( FALSE );
+    tcflush( serial_fd, TCIOFLUSH );
+    fprintf( stderr,
+        "xdemorse: read(): incorrect number of bytes available:"
+        " %d/%d after %d tries\n", nbytes, (int)len, cnt );
+    data[0] = '\0';
+    Cancel_CAT();
+    return( FALSE );
   }
 
   /* Clear data buffer and read from serial */
@@ -99,13 +98,13 @@ Read_Tcvr_Serial( char *data, size_t len )
   /* Error condition */
   if( ret != len )
   {
-	tcflush( serial_fd, TCIOFLUSH );
-	fprintf( stderr,
-		"xdemorse: read() return value wrong: %d/%d\n",
-		(int)ret, (int)len );
-	data[0] = '\0';
-	Cancel_CAT();
-	return( FALSE );
+    tcflush( serial_fd, TCIOFLUSH );
+    fprintf( stderr,
+        "xdemorse: read() return value wrong: %d/%d\n",
+        (int)ret, (int)len );
+    data[0] = '\0';
+    Cancel_CAT();
+    return( FALSE );
   }
 
   return( TRUE );
@@ -126,28 +125,28 @@ Write_Tcvr_Serial( char *data, size_t len )
 
   /* Flush serial and write command, retrying if needed */
   if( isFlagClear(TCVR_SERIAL_TEST) &&
-	  isFlagClear(CAT_SETUP) )
-	return( FALSE );
+      isFlagClear(CAT_SETUP) )
+    return( FALSE );
   tcflush( serial_fd, TCIOFLUSH );
   while( cnt++ < MAX_SERIAL_RETRIES )
   {
-	ret = (size_t)write( serial_fd, data, len );
-	if( ret == len ) break;
-	fprintf( stderr,
-		"xdemorse: write(): incorrect number of bytes written:"
-		" %d/%d\n", (int)ret, (int)len );
-	usleep( 100000 );
+    ret = (size_t)write( serial_fd, data, len );
+    if( ret == len ) break;
+    fprintf( stderr,
+        "xdemorse: write(): incorrect number of bytes written:"
+        " %d/%d\n", (int)ret, (int)len );
+    usleep( 100000 );
   }
 
   /* Error condition */
    if( cnt >= MAX_SERIAL_RETRIES )
   {
-	tcflush( serial_fd, TCIOFLUSH );
-	fprintf( stderr,
-		"xdemorse: write(): incorrect number of bytes written:"
-		" %d/%d after %d tries\n", (int)ret, (int)len, cnt );
-	Cancel_CAT();
-	return( FALSE );
+    tcflush( serial_fd, TCIOFLUSH );
+    fprintf( stderr,
+        "xdemorse: write(): incorrect number of bytes written:"
+        " %d/%d after %d tries\n", (int)ret, (int)len, cnt );
+    Cancel_CAT();
+    return( FALSE );
   }
 
   /* Give time to CAT to do its thing */
@@ -175,40 +174,40 @@ Read_Rx_Freq( int *freq )
 
   switch( rc_data.receiver_type )
   {
-	case FT847: case FT857:
-	/* Read Rx frequency */
-	memset( frq, 0, sizeof(frq) );
-	if( !Write_Tcvr_Serial(FT847_MAIN_VFO, sizeof(FT847_MAIN_VFO)) ||
-		!Read_Tcvr_Serial(frq, sizeof(frq)) )
-	  return( FALSE );
+    case FT847: case FT857:
+    /* Read Rx frequency */
+    memset( frq, 0, sizeof(frq) );
+    if( !Write_Tcvr_Serial(FT847_MAIN_VFO, sizeof(FT847_MAIN_VFO)) ||
+        !Read_Tcvr_Serial(frq, sizeof(frq)) )
+      return( FALSE );
 
-	/* Decode frequency data to 10Hz */
-	*freq = 0;
-	*freq += (frq[0] & 0xF0) >> 4;
-	*freq *= 10;
-	*freq += frq[0] & 0x0F;
-	*freq *= 10;
-	*freq += (frq[1] & 0xF0) >> 4;
-	*freq *= 10;
-	*freq += frq[1] & 0x0F;
-	*freq *= 10;
-	*freq += (frq[2] & 0xF0) >> 4;
-	*freq *= 10;
-	*freq += frq[2] & 0x0F;
-	*freq *= 10;
-	*freq += (frq[3] & 0xF0) >> 4;
-	*freq *= 10;
-	*freq += frq[3] & 0x0F;
-	*freq *= 10;
-	break;
+    /* Decode frequency data to 10Hz */
+    *freq = 0;
+    *freq += (frq[0] & 0xF0) >> 4;
+    *freq *= 10;
+    *freq += frq[0] & 0x0F;
+    *freq *= 10;
+    *freq += (frq[1] & 0xF0) >> 4;
+    *freq *= 10;
+    *freq += frq[1] & 0x0F;
+    *freq *= 10;
+    *freq += (frq[2] & 0xF0) >> 4;
+    *freq *= 10;
+    *freq += frq[2] & 0x0F;
+    *freq *= 10;
+    *freq += (frq[3] & 0xF0) >> 4;
+    *freq *= 10;
+    *freq += frq[3] & 0x0F;
+    *freq *= 10;
+    break;
 
-	case K2: case K3:
-	/* Read Rx frequency */
-	if( !Write_Tcvr_Serial(K3_VFOA_G, sizeof(K3_VFOA_G)-1) ||
-		!Read_Tcvr_Serial(K3_VFOA_S, sizeof(K3_VFOA_S)-1) )
-	  return( FALSE );
-	*freq = atoi( K3_VFOA_S + 2 );
-	break;
+    case K2: case K3:
+    /* Read Rx frequency */
+    if( !Write_Tcvr_Serial(K3_VFOA_G, sizeof(K3_VFOA_G)-1) ||
+        !Read_Tcvr_Serial(K3_VFOA_S, sizeof(K3_VFOA_S)-1) )
+      return( FALSE );
+    *freq = atoi( K3_VFOA_S + 2 );
+    break;
 
   } /* switch( rc_data.receiver_type ) */
 
@@ -235,30 +234,30 @@ Write_Rx_Freq( int freq )
 
   switch( rc_data.receiver_type )
   {
-	case FT847: case FT857:
-	  /* Set Rx frequency */
-	  snprintf( freq_buff, sizeof(freq_buff), "%08d", freq/10 );
-	  for( idx = 0; idx < 4; idx++ )
-	  {
-		FT847_SET_VFO[idx]  = (char)((freq_buff[2*idx]   - '0') << 4);
-		FT847_SET_VFO[idx] |= (char)( freq_buff[2*idx+1] - '0');
-	  }
-	  if( !Write_Tcvr_Serial(FT847_SET_VFO, sizeof(FT847_SET_VFO)) )
-		return( FALSE );
-	  break;
+    case FT847: case FT857:
+      /* Set Rx frequency */
+      snprintf( freq_buff, sizeof(freq_buff), "%08d", freq/10 );
+      for( idx = 0; idx < 4; idx++ )
+      {
+        FT847_SET_VFO[idx]  = (char)((freq_buff[2*idx]   - '0') << 4);
+        FT847_SET_VFO[idx] |= (char)( freq_buff[2*idx+1] - '0');
+      }
+      if( !Write_Tcvr_Serial(FT847_SET_VFO, sizeof(FT847_SET_VFO)) )
+        return( FALSE );
+      break;
 
-	case K2: case K3:
-	  /* Set Rx frequency */
-	  snprintf( K3_VFOA_S+2, sizeof(K3_VFOA_S)-2, "%011d;", freq );
-	  if( !Write_Tcvr_Serial(K3_VFOA_S, sizeof(K3_VFOA_S)-1) )
-		  return( FALSE );
-	  break;
+    case K2: case K3:
+      /* Set Rx frequency */
+      snprintf( K3_VFOA_S+2, sizeof(K3_VFOA_S)-2, "%011d;", freq );
+      if( !Write_Tcvr_Serial(K3_VFOA_S, sizeof(K3_VFOA_S)-1) )
+          return( FALSE );
+      break;
 
 #ifdef HAVE_LIBPERSEUS_SDR
-	 /* Set Perseus frequency */
-	case PERSEUS:
-	  Perseus_Set_Center_Frequency( freq );
-	  break;
+     /* Set Perseus frequency */
+    case PERSEUS:
+      Perseus_Set_Center_Frequency( freq );
+      break;
 #endif
 
   } /* switch( rc_data.receiver_type ) */
@@ -289,15 +288,15 @@ Open_Tcvr_Serial( void )
   serial_fd = open( rc_data.cat_serial, O_RDWR | O_NOCTTY );
   if( serial_fd < 0 )
   {
-	char mesg[MESG_SIZE];
-	perror( rc_data.cat_serial );
-	snprintf( mesg, sizeof(mesg),
-		_("Failed to open %s\n"\
-		  "Transceiver CAT not setup"),
-		rc_data.cat_serial );
-	Error_Dialog( mesg );
-	serial_fd = 0;
-	return( FALSE );
+    char mesg[MESG_SIZE];
+    perror( rc_data.cat_serial );
+    snprintf( mesg, sizeof(mesg),
+        _("Failed to open %s\n"\
+          "Transceiver CAT not setup"),
+        rc_data.cat_serial );
+    Error_Dialog( mesg );
+    serial_fd = 0;
+    return( FALSE );
   }
 
   /* Attempt to lock entire Serial port device file */
@@ -310,20 +309,20 @@ Open_Tcvr_Serial( void )
   error = fcntl( serial_fd, F_SETLK, &lockinfo );
   if( error == -1 )
   {
-	char mesg[MESG_SIZE];
-	error = fcntl( serial_fd, F_GETLK, &lockinfo );
-	if( error != -1 )
-	{
-	  snprintf( mesg, sizeof(mesg),
-		  _("Failed to lock %s\n"\
-			"Device locked by pid %d\n"\
-			"Transceiver CAT not setup"),
-		  rc_data.cat_serial, lockinfo.l_pid );
-	  Error_Dialog( mesg );
-	}
-	close( serial_fd );
-	serial_fd = 0;
-	return( FALSE );
+    char mesg[MESG_SIZE];
+    error = fcntl( serial_fd, F_GETLK, &lockinfo );
+    if( error != -1 )
+    {
+      snprintf( mesg, sizeof(mesg),
+          _("Failed to lock %s\n"\
+            "Device locked by pid %d\n"\
+            "Transceiver CAT not setup"),
+          rc_data.cat_serial, lockinfo.l_pid );
+      Error_Dialog( mesg );
+    }
+    close( serial_fd );
+    serial_fd = 0;
+    return( FALSE );
   }
 
   /* Save the current serial port options */
@@ -335,13 +334,13 @@ Open_Tcvr_Serial( void )
   /* Set the i/o baud rates */
   switch( rc_data.receiver_type )
   {
-	case FT847:
-	  error |= cfsetspeed( &new_options, B57600 );
-	  break;
+    case FT847:
+      error |= cfsetspeed( &new_options, B57600 );
+      break;
 
-	case FT857: case K2: case K3:
-	  error |= cfsetspeed( &new_options, B38400 );
-	  break;
+    case FT857: case K2: case K3:
+      error |= cfsetspeed( &new_options, B38400 );
+      break;
   }
 
   /* Set options for 'raw' I/O mode */
@@ -359,61 +358,61 @@ Open_Tcvr_Serial( void )
   Set_Flag( TCVR_SERIAL_TEST );
   switch( rc_data.receiver_type )
   {
-	case FT847:
-	  if( !Write_Tcvr_Serial(FT847_CAT_ON, sizeof(FT847_CAT_ON)) ||
-		  !Write_Tcvr_Serial(FT847_MAIN_VFO, sizeof(FT847_MAIN_VFO)) ||
-		  !Read_Tcvr_Serial(test, 5) )
-	  {
-		fprintf( stderr, "xdemorse: failed to enable FT847 CAT\n" );
-		Write_Tcvr_Serial( FT847_CAT_OFF, sizeof(FT847_CAT_OFF) );
-		Cancel_CAT();
-		return( FALSE );
-	  }
-	  Write_Tcvr_Serial( FT847_MODE_CWNR, sizeof(FT847_MODE_CWNR) );
-	  break;
+    case FT847:
+      if( !Write_Tcvr_Serial(FT847_CAT_ON, sizeof(FT847_CAT_ON)) ||
+          !Write_Tcvr_Serial(FT847_MAIN_VFO, sizeof(FT847_MAIN_VFO)) ||
+          !Read_Tcvr_Serial(test, 5) )
+      {
+        fprintf( stderr, "xdemorse: failed to enable FT847 CAT\n" );
+        Write_Tcvr_Serial( FT847_CAT_OFF, sizeof(FT847_CAT_OFF) );
+        Cancel_CAT();
+        return( FALSE );
+      }
+      Write_Tcvr_Serial( FT847_MODE_CWNR, sizeof(FT847_MODE_CWNR) );
+      break;
 
-	case FT857:
-	  if( !Write_Tcvr_Serial(FT847_MAIN_VFO, sizeof(FT847_MAIN_VFO)) ||
-		  !Read_Tcvr_Serial(test, 5) )
-	  {
-		fprintf( stderr, "xdemorse: failed to enable FT857 CAT\n" );
-		Cancel_CAT();
-		return( FALSE );
-	  }
-	  Write_Tcvr_Serial( FT847_MODE_CWR, sizeof(FT847_MODE_CWR) );
-	  break;
+    case FT857:
+      if( !Write_Tcvr_Serial(FT847_MAIN_VFO, sizeof(FT847_MAIN_VFO)) ||
+          !Read_Tcvr_Serial(test, 5) )
+      {
+        fprintf( stderr, "xdemorse: failed to enable FT857 CAT\n" );
+        Cancel_CAT();
+        return( FALSE );
+      }
+      Write_Tcvr_Serial( FT847_MODE_CWR, sizeof(FT847_MODE_CWR) );
+      break;
 
-	case K2:
-	  /* Get K2 VFO A as a test of serial port */
-	  if( !Write_Tcvr_Serial(K3_VFOA_G, sizeof(K3_VFOA_G)-1) ||
-		  !Read_Tcvr_Serial(K3_VFOA_S, sizeof(K3_VFOA_S)-1) )
-	  {
-		fprintf( stderr, "xdemorse: failed to enable K2 CAT\n" );
-		Cancel_CAT();
-		return( FALSE );
-	  }
-	  Write_Tcvr_Serial( K3_MODE_CWR, sizeof(K3_MODE_CWR)-1 );
-	  break;
+    case K2:
+      /* Get K2 VFO A as a test of serial port */
+      if( !Write_Tcvr_Serial(K3_VFOA_G, sizeof(K3_VFOA_G)-1) ||
+          !Read_Tcvr_Serial(K3_VFOA_S, sizeof(K3_VFOA_S)-1) )
+      {
+        fprintf( stderr, "xdemorse: failed to enable K2 CAT\n" );
+        Cancel_CAT();
+        return( FALSE );
+      }
+      Write_Tcvr_Serial( K3_MODE_CWR, sizeof(K3_MODE_CWR)-1 );
+      break;
 
-	case K3:
-	  /* Set K3 to mode K31 as a test of serial port */
-	  Strlcpy( K3_K31_S, "K31;", sizeof(K3_K31_S) );
-	  if( !Write_Tcvr_Serial(K3_K31_S, sizeof(K3_K31_S)-1) )
-	  {
-		fprintf( stderr, "xdemorse: failed to enable K3 CAT\n" );
-		Cancel_CAT();
-		return( FALSE );
-	  }
-	  if( !Write_Tcvr_Serial(K3_K31_G, sizeof(K3_K31_G)-1) ||
-		  !Read_Tcvr_Serial(K3_K31_S, sizeof(K3_K31_S)-1) ||
-		  (strcmp(K3_K31_S, "K31;") != 0) )
-	  {
-		fprintf( stderr, "xdemorse: failed to enable K3 CAT\n" );
-		Cancel_CAT();
-		return( FALSE );
-	  }
-	  Write_Tcvr_Serial( K3_MODE_CWR, sizeof(K3_MODE_CWR)-1 );
-	  break;
+    case K3:
+      /* Set K3 to mode K31 as a test of serial port */
+      Strlcpy( K3_K31_S, "K31;", sizeof(K3_K31_S) );
+      if( !Write_Tcvr_Serial(K3_K31_S, sizeof(K3_K31_S)-1) )
+      {
+        fprintf( stderr, "xdemorse: failed to enable K3 CAT\n" );
+        Cancel_CAT();
+        return( FALSE );
+      }
+      if( !Write_Tcvr_Serial(K3_K31_G, sizeof(K3_K31_G)-1) ||
+          !Read_Tcvr_Serial(K3_K31_S, sizeof(K3_K31_S)-1)  ||
+          (strncmp(K3_K31_S, "K31;", sizeof(K3_K31_S)) != 0) )
+      {
+        fprintf( stderr, "xdemorse: failed to enable K3 CAT\n" );
+        Cancel_CAT();
+        return( FALSE );
+      }
+      Write_Tcvr_Serial( K3_MODE_CWR, sizeof(K3_MODE_CWR)-1 );
+      break;
 
   } /* switch( rc_data.receiver_type ) */
 
@@ -435,17 +434,17 @@ Close_Tcvr_Serial( void )
 {
   if( isFlagSet(CAT_SETUP) )
   {
-	/* Disable CAT for FT847 */
-	if( rc_data.receiver_type == FT847 )
-	  Write_Tcvr_Serial( FT847_CAT_OFF, sizeof(FT847_CAT_OFF) );
+    /* Disable CAT for FT847 */
+    if( rc_data.receiver_type == FT847 )
+      Write_Tcvr_Serial( FT847_CAT_OFF, sizeof(FT847_CAT_OFF) );
 
-	/* Restore serial port and close */
-	if( serial_fd > 0 )
-	{
-	  tcsetattr( serial_fd, TCSANOW, &tcvr_serial_old_options );
-	  close( serial_fd );
-	  serial_fd = 0;
-	}
+    /* Restore serial port and close */
+    if( serial_fd > 0 )
+    {
+      tcsetattr( serial_fd, TCSANOW, &tcvr_serial_old_options );
+      close( serial_fd );
+      serial_fd = 0;
+    }
   }
 
   Clear_Flag( CAT_SETUP );
@@ -463,11 +462,11 @@ Close_Tcvr_Serial( void )
 Tune_Tcvr( double x )
 {
   int
-	from, to,	/* Range to scan for a max bin value  */
-	bin_max,	/* Max bin value found in this range  */
-	max_idx,	/* ifft idx at which the max is found */
-	ifft_idx,	/* Idx used to search ifft bin values */
-	audio_freq;	/* Audio frequency in waterfal window */
+    from, to,   /* Range to scan for a max bin value  */
+    bin_max,    /* Max bin value found in this range  */
+    max_idx,    /* ifft idx at which the max is found */
+    ifft_idx,   /* Idx used to search ifft bin values */
+    audio_freq; /* Audio frequency in waterfal window */
 
   /* Abort if serial already open */
   if( isFlagClear(CAT_SETUP) ) return( TRUE );
@@ -487,11 +486,11 @@ Tune_Tcvr( double x )
   bin_max = 0;
   max_idx = ifft_idx;
   for( ifft_idx = from; ifft_idx < to; ifft_idx++ )
-	if( bin_max < bin_ave[ifft_idx] )
-	{
-	  bin_max = bin_ave[ifft_idx];
-	  max_idx = ifft_idx;
-	}
+    if( bin_max < bin_ave[ifft_idx] )
+    {
+      bin_max = bin_ave[ifft_idx];
+      max_idx = ifft_idx;
+    }
 
   /* Audio frequency corresponding to ifft index. Since the
    * waterfall width has to be an odd number so that a center
@@ -505,10 +504,10 @@ Tune_Tcvr( double x )
 
   if( rc_data.receiver_type != PERSEUS )
   {
-	/* Read current Rx frequency */
-	rc_data.receiver_freq = 0;
-	if( !Read_Rx_Freq(&rc_data.receiver_freq) )
-	  return( FALSE );
+    /* Read current Rx frequency */
+    rc_data.receiver_freq = 0;
+    if( !Read_Rx_Freq(&rc_data.receiver_freq) )
+      return( FALSE );
   }
 
   /* Add frequency correction */
